@@ -22,13 +22,13 @@ def main():
 	import glob
 	
 	from pypykatz.utils.crypto.cmdhelper import CryptoCMDHelper
-	from pypykatz.ldap.cmdhelper import LDAPCMDHelper
+	#from pypykatz.ldap.cmdhelper import LDAPCMDHelper
 	from pypykatz.kerberos.cmdhelper import KerberosCMDHelper
 	from pypykatz.lsadecryptor.cmdhelper import LSACMDHelper
 	from pypykatz.registry.cmdhelper import RegistryCMDHelper
 	from pypykatz.remote.cmdhelper import RemoteCMDHelper
 	
-	cmdhelpers = [LSACMDHelper(), RegistryCMDHelper(), CryptoCMDHelper(), LDAPCMDHelper(), KerberosCMDHelper(), RemoteCMDHelper()]
+	cmdhelpers = [LSACMDHelper(), RegistryCMDHelper(), CryptoCMDHelper(), KerberosCMDHelper(), RemoteCMDHelper()] #LDAPCMDHelper(),
 	
 
 	parser = argparse.ArgumentParser(description='Pure Python implementation of Mimikatz --and more--')
@@ -108,6 +108,8 @@ def main():
 	dpapi_vpol_group.add_argument('-m', '--mkb-file', help= 'Keyfile generated by the masterkey -o command.')
 	
 	sake_group = subparsers.add_parser('sake', help='sake')
+	version_group = subparsers.add_parser('version', help='version')
+	banner_group = subparsers.add_parser('banner', help='banner')
 	
 	####### PARSING ARGUMENTS
 	
@@ -124,8 +126,8 @@ def main():
 		logging.basicConfig(level=level)
 	
 	##### Common obj
-	results = {}
-	files_with_error = []
+	#results = {}
+	#files_with_error = []
 	
 	for helper in cmdhelpers:
 		helper.execute(args)
@@ -328,6 +330,14 @@ def main():
 		from pypykatz.utils.sake.sake import Sake
 		s = Sake()
 		print(s.draw())
+
+	elif args.command == 'version':
+		from pypykatz._version import __version__
+		print(__version__)
+	
+	elif args.command == 'banner':
+		from pypykatz._version import __banner__
+		print(__banner__)
 					
 	
 	
