@@ -4,10 +4,11 @@
 #  Tamas Jos (@skelsec)
 #
 import io
-from minidump.win_datatypes import *
-from pypykatz.commons.common import *
-from pypykatz.commons.win_datatypes import *
-from pypykatz.lsadecryptor.package_commons import *
+from minidump.win_datatypes import BOOLEAN, HANDLE
+from pypykatz.commons.common import KatzSystemArchitecture, WindowsMinBuild, WindowsBuild
+from pypykatz.commons.win_datatypes import USHORT, ULONG, LSA_UNICODE_STRING, LSAISO_DATA_BLOB, \
+	BYTE, PVOID, WORD, DWORD, POINTER, LUID, PSID, ANSI_STRING
+from pypykatz.lsadecryptor.package_commons import PackageTemplate
 
 class MsvTemplate(PackageTemplate):
 	def __init__(self):
